@@ -220,7 +220,7 @@ pgInsertizeGeom <- function(data.obj, geom = "geom", create.table = NULL,
             dat<-dbWriteDataFrame(conn, in.tab, dat , only.defs = TRUE)
           } else {
             # remove existing defs if table exists
-            if (dbExistsTable(conn, ".R_df_defs")) {
+            if (dbExistsTable(conn, ".R_df_defs", table.only = TRUE)) {
               sql_query<-paste0("DELETE FROM \".R_df_defs\" WHERE table_nm = ",
                 dbQuoteString(conn, in.tab[length(in.tab)]),";")
               dbExecute(conn, sql_query)
@@ -440,7 +440,7 @@ pgInsertize <- function(data.obj, create.table = NULL, force.match = NULL,
           data.obj<-dbWriteDataFrame(conn, in.tab, data.obj, only.defs = TRUE)
         } else {
           # remove existing defs if table exists
-          if (dbExistsTable(conn, ".R_df_defs")) {
+          if (dbExistsTable(conn, ".R_df_defs", table.only = TRUE)) {
             sql_query<-paste0("DELETE FROM \".R_df_defs\" WHERE table_nm = ",
               dbQuoteString(conn, in.tab[length(in.tab)]),";")
             dbExecute(conn, sql_query)
